@@ -23,6 +23,17 @@ class CruiseConnection(object):
             print("WARNING DB failed to connect. Script closing", e)
             raise e
 
+    def execute(self, command, data=None):
+        with self.__get_connection() as connection:
+            try:
+                cursor = connection.cursor()
+                cursor.execute(command, data)
+                connection.commit()
+            except Exception as e:
+                MigrationLog.logger.error("Statement execution failed due to error:")
+                MigrationLog.log_exception(e)
+                raise RuntimeError("statement execution failed.")
+
     def executemany(self, command, data=None):
         with self.__get_connection() as connection:
             try:
