@@ -98,7 +98,7 @@ class MigrationReport(LoggerBuilder):
         MigrationReport.failed_surveys.append(FailedSurvey(survey_crate.mb_survey.survey_name, message))
 
     @staticmethod
-    def final_report():
+    def migration_final_report():
         logger = MigrationReport.logger
         total_migrated_surveys = len(MigrationReport.migrated_surveys)
         total_failed_surveys = len(MigrationReport.failed_surveys)
@@ -147,11 +147,21 @@ class MigrationReport(LoggerBuilder):
 
         print("MIGRATION COMPLETED: Elapsed time: ", total_time)
 
+    @staticmethod
+    def clean_final_report():
+        logger = MigrationReport.logger
+        total_time = (MigrationReport.end - MigrationReport.start).total_seconds() / 60
+
+        logger.info(f"DELETION OF MULTIBEAM DATA COMPLETED")
+        logger.info(f'Elapsed time in minutes: {total_time}')
+        logger.info(f"\r")
+
     @staticmethod
     def get_successful_surveys_without_problems():
         successful = MigrationReport.migrated_surveys
         problems = MigrationReport.problem_surveys
-        if problems:
-            successful = [survey for survey in MigrationReport.migrated_surveys not in problems]
+        problems = [problem.survey_name for problem in problems]
+        if problems and successful:
+            successful = [survey for survey in successful not in problems]
 
         return successful
