@@ -115,7 +115,8 @@ class CruiseProcessor(object):
         self.dataset_scientist_mappings.extend(self.__package_mappings(dataset.id, self.__get_entity_ids(scientists)))
         self.dataset_source_mappings.extend(self.__package_mappings(dataset.id, self.__get_entity_ids(sources)))
         self.dataset_instrument_mappings.extend(self.__package_mappings(dataset.id, self.__get_entity_ids(instruments)))
-        self.dataset_project_mappings.extend(self.__package_mappings(dataset.id, [project.id]))
+        if project:
+            self.dataset_project_mappings.extend(self.__package_mappings(dataset.id, [project.id]))
 
         for crate in file_crates:
             crate.file.dataset_id = dataset.id
@@ -246,7 +247,8 @@ class CruiseProcessor(object):
         return instruments
 
     def __process_project(self, project_crate: CruiseProjectCrate):
-        return self.project_service.get_new_or_existing_project(project_crate.project)
+        project = project_crate.project
+        return self.project_service.get_new_or_existing_project(project) if project else None
 
     def __process_access_path(self, access_path: CruiseAccessPath):
         cached_access_path = self.access_path_cache.request(
@@ -396,8 +398,7 @@ class CruiseProcessor(object):
                 self.__fail_dataset(dataset, "instrument")
                 valid = False
         if project is None:
-            self.__fail_dataset(dataset, "project")
-            valid = False
+            valid = True  # project not required
         if not valid:
             raise RuntimeWarning("Issue found with dataset or dataset related tables.")
 
