@@ -125,7 +125,7 @@ class SchemaMapper(object):
                     last = None
                     name = first
                 else:
-                    raise ValueError("Unexpected chief scientist field value.")
+                    raise ValueError(f"Unexpected chief scientist field value in survey {mb_survey.survey_name}.")
                 scientists.append(
                     CruisePeopleAndSources(
                         first=first,
@@ -188,11 +188,14 @@ class SchemaMapper(object):
 
     @staticmethod
     def load_cruise_survey(mb_survey: MbSurvey) -> CruiseSurvey:
+        start_time = mb_survey.start_time.strftime('%Y-%m-%dT%H:%M:%S') if mb_survey.start_time else None
+        end_time = mb_survey.end_time.strftime('%Y-%m-%dT%H:%M:%S') if mb_survey.end_time else None  # previously '%d-%b-%y'
+
         survey_name = mb_survey.survey_name        # MB.SURVEY.SURVEY_NAME
         parent = None                              # N/A
         platform_name = mb_survey.ship_name        # MB.SURVEY.SHIP_NAME
-        start_date = mb_survey.start_time          # MB.SURVEY.START_TIME
-        end_date = mb_survey.end_time              # MB.SURVEY.END_TIME
+        start_date = start_time                    # MB.SURVEY.START_TIME
+        end_date = end_time                        # MB.SURVEY.END_TIME-
         departure_port = mb_survey.departure_port  # MB.SURVEY.DEPARTURE_PORT
         arrival_port = mb_survey.arrival_port      # MB.SURVEY.ARRIVAL_PORT
 
@@ -287,8 +290,9 @@ class SchemaMapper(object):
     @staticmethod
     def load_cruise_project(mb_survey: MbSurvey) -> [CruiseProject]:
         """in practice will be a singleton list"""
-        project = CruiseProject(project_name=mb_survey.project_name)  # MB.SURVEY.PROJECT_NAME
-        return project
+        project_name = mb_survey.project_name
+
+        return CruiseProject(project_name=mb_survey.project_name) if project_name else None  # MB.SURVEY.PROJECT_NAME
 
     @staticmethod
     def load_cruise_project_parameters() -> [CruiseProjectParameter]:
@@ -316,6 +320,7 @@ class SchemaMapper(object):
         raw_size = mb_file.filesize  # MB.NGDCID_AND_FILE.FILESIZE
         publish = "Y" if mb_file.publish.upper() == "yes".upper() else "N"  # derived directly from MB.NGDCID_AND_FILE.PUBLISH
         collection_date = mb_file.entry_date  # MB.NGDCID_AND_FILE.ENTRY_DATE
+        # collection_date = file_crate.mb_info.start_time.strftime('%d-%b-%y %H:%M:%S') if file_crate.mb_info and file_crate.mb_info.start_time else None
         publish_date = mb_file.process_date  # MB.NGDCID_AND_FILE.PROCESS_DATE
         archive_date = mb_file.process_date  # MB.NGDCID_AND_FILE.PROCESS_DATE
         temp_id = None
