@@ -1,5 +1,6 @@
 import unittest
 
+from src.mb_cruise_migration.logging.migration_log import MigrationLog
 from src.mb_cruise_migration.migration_properties import MigrationProperties
 from src.mb_cruise_migration.framework.consts.const_initializer import ConstInitializer
 from src.mb_cruise_migration.processors.mb_processor import MbProcessor
@@ -8,6 +9,7 @@ from tests.testutils import load_test_mb_data, clean_mb_db
 
 class TestSurveyBlacklist(unittest.TestCase):
     MigrationProperties("config_test.yaml")
+    MigrationLog()
 
     def setUp(self) -> None:
         self.tearDown()
